
# Firecrawl MCP Server

An MCP Server for the Firecrawl API.

## Supported Integrations

- AgentR
- API Key (Coming Soon)
- OAuth (Coming Soon)

## Tools

This is automatically generated from OpenAPI schema for the Firecrawl API.

## Supported Integrations

This tool can be integrated with any service that supports HTTP requests.

## Tool List

| Tool | Description |
|------|-------------|
| scrape_url | Scrapes a single URL using Firecrawl and returns the extracted data. |
| search | Performs a web search using Firecrawl's search capability. |
| start_crawl | Starts a crawl job for a given URL using Firecrawl. Returns the job ID immediately. |
| check_crawl_status | Checks the status of a previously initiated Firecrawl crawl job. |
| cancel_crawl | Cancels a currently running Firecrawl crawl job. |
| start_batch_scrape | Starts a batch scrape job for multiple URLs using Firecrawl. |
| check_batch_scrape_status | Checks the status of a previously initiated Firecrawl batch scrape job. |
| start_extract | Starts an extraction job for one or more URLs using Firecrawl. |
| check_extract_status | Checks the status of a previously initiated Firecrawl extraction job. |



## Usage

- Login to AgentR
- Follow the quickstart guide to setup MCP Server for your client
- Visit Apps Store and enable the Firecrawl app
- Restart the MCP Server

### Local Development

- Follow the README to test with the local MCP Server
